@@ -1,6 +1,6 @@
 package CatalystX::Resource::Controller::Resource;
 {
-    $CatalystX::Resource::Controller::Resource::VERSION = '0.001_006';
+    $CatalystX::Resource::Controller::Resource::VERSION = '0.003_001';
 }
 use Moose;
 use namespace::autoclean;
@@ -39,6 +39,12 @@ has 'model' => (
     required => 1,
 );
 
+has 'identifier_columns' => (
+    is      => 'ro',
+    isa     => 'ArrayRef',
+    default => sub { [qw/ name title /] },
+);
+
 has 'resultset_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
@@ -88,25 +94,13 @@ sub _redirect {
     my @captures = @{ $c->request->captures };
     my $action   = $c->action->name;
 
-    ##############################
-    # move_next || move_previous #
-    ##############################
-# path: /parents/1/resources/1/move_next        => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/1/move_previous    => redirect_path: /parents/1/resources/list
-# path: /resources/1/move_next                  => redirect_path: /resources/list
-# path: /resources/1/move_previous              => redirect_path: /resources/list
-    if ( $action eq 'move_next' || $action eq 'move_previous' ) {
-        pop(@captures);
-        $path = $c->uri_for_action( $self->action_for('list'), \@captures );
-    }
-
     ########################
     # redirect_mode 'list' #
     ########################
-# path: /parents/1/resources/create   => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/3/edit   => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/3/delete => redirect_path: /parents/1/resources/list
-    elsif ( $mode eq 'list' ) {
+# path: /parents/1/resources/create      => redirect_path: /parents/1/resources/list
+# path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/list
+# path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
+    if ( $mode eq 'list' ) {
         pop(@captures)
             unless $action eq 'create';
         $path = $c->uri_for_action( $self->action_for('list'), \@captures );
@@ -115,9 +109,9 @@ sub _redirect {
     ########################
     # redirect_mode 'show' #
     ########################
-# path: /parents/1/resources/create   => redirect_path: /parents/1/resources/<id>/show
-# path: /parents/1/resources/3/edit   => redirect_path: /parents/1/resources/3/show
-# path: /parents/1/resources/3/delete => redirect_path: /parents/1/resources/list
+# path: /parents/1/resources/create      => redirect_path: /parents/1/resources/<id>/show
+# path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/3/show
+# path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
     elsif ( $mode eq 'show' ) {
         if ( $action eq 'create' ) {
             my $id_of_created_resource
@@ -126,26 +120,26 @@ sub _redirect {
             $path
                 = $c->uri_for_action( $self->action_for('show'), \@captures );
         }
-        elsif ( $action eq 'edit' ) {
-            $path
-                = $c->uri_for_action( $self->action_for('show'), \@captures );
-        }
         elsif ( $action eq 'delete' ) {
             pop(@captures);
             $path
                 = $c->uri_for_action( $self->action_for('list'), \@captures );
         }
+        elsif ( $action eq 'edit' ) {
+            $path
+                = $c->uri_for_action( $self->action_for('show'), \@captures );
+        }
     }
 
     ###############################
     # redirect_mode 'show_parent' #
     ###############################
-    # path: /parents/1/resources/create   => redirect_path: /parents/1/show
-    # path: /resources/create             => redirect_path: /resources/list
-    # path: /parents/1/resources/3/edit   => redirect_path: /parents/1/show
-    # path: /resources/3/edit             => redirect_path: /resources/list
-    # path: /parents/1/resources/3/delete => redirect_path: /parents/1/show
-    # path: /resources/3/delete           => redirect_path: /resources/list
+    # path: /parents/1/resources/create      => redirect_path: /parents/1/show
+    # path: /resources/create                => redirect_path: /resources/list
+    # path: /parents/1/resources/3/edit      => redirect_path: /parents/1/show
+    # path: /resources/3/edit                => redirect_path: /resources/list
+    # path: /parents/1/resources/3/delete    => redirect_path: /parents/1/show
+    # path: /resources/3/delete              => redirect_path: /resources/list
     elsif ( $mode eq 'show_parent' ) {
         if ( $self->has_parent ) {
             my @chain
@@ -156,7 +150,9 @@ sub _redirect {
             if ( $action eq 'create' ) {
                 $parent_base_with_id_action = $chain[-3];
             }
-            elsif ( $action eq 'edit' || $action eq 'delete' ) {
+            elsif ($action eq 'edit'
+                || $action eq 'delete' )
+            {
                 $parent_base_with_id_action = $chain[-4];
                 pop @captures;
             }
@@ -187,39 +183,50 @@ sub _msg {
     }
     elsif ( $action eq 'create' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.created', $self->_name($c) )
-            : $self->_name($c) . " created.";
+            ? $c->loc( 'resources.created', $self->_identifier($c) )
+            : $self->_identifier($c) . " created.";
     }
     elsif ( $action eq 'update' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.updated', $self->_name($c) )
-            : $self->_name($c) . " updated.";
+            ? $c->loc( 'resources.updated', $self->_identifier($c) )
+            : $self->_identifier($c) . " updated.";
     }
     elsif ( $action eq 'delete' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.deleted', $self->_name($c) )
-            : $self->_name($c) . " deleted.";
+            ? $c->loc( 'resources.deleted', $self->_identifier($c) )
+            : $self->_identifier($c) . " deleted.";
     }
     elsif ( $action eq 'move_next' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.moved_next', $self->_name($c) )
-            : $self->_name($c) . " moved next.";
+            ? $c->loc( 'resources.moved_next', $self->_identifier($c) )
+            : $self->_identifier($c) . " moved next.";
     }
     elsif ( $action eq 'move_previous' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.moved_previous', $self->_name($c) )
-            : $self->_name($c) . " moved previous.";
+            ? $c->loc( 'resources.moved_previous', $self->_identifier($c) )
+            : $self->_identifier($c) . " moved previous.";
+    }
+    elsif ( $action eq 'move_to' ) {
+        return $c->can('loc')
+            ? $c->loc( 'resources.moved_to', $self->_identifier($c) )
+            : $self->_identifier($c) . " moved.";
     }
 }
 
-sub _name {
+sub _identifier {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
-    my $name
-        = $resource->result_source->has_column('name')
-        ? $resource->name
-        : ucfirst( $self->resource_key );
-    return $name;
+
+    for my $col ( @{ $self->identifier_columns } ) {
+        if (   $resource->result_source->has_column($col)
+            && defined $resource->$col
+            && $resource->$col )
+        {
+            return $resource->$col;
+        }
+    }
+
+    return ucfirst( $self->resource_key );
 }
 
 sub base : Chained('') PathPart('') CaptureArgs(0) {
@@ -263,7 +270,7 @@ CatalystX::Resource::Controller::Resource - Base Controller for Resources
 
 =head1 VERSION
 
-version 0.001_006
+version 0.003_001
 
 =head1 ATTRIBUTES
 
@@ -271,6 +278,19 @@ version 0.001_006
 
 required, the DBIC model associated with this resource. (e.g.: 'DB::CDs')
 
+=head2 identifier_columns
+
+ArrayRef of column names used as name in messages.
+
+if you edit, delete, ... a resource a msg is stored in the stash.
+the first defined value of the provided columns will be used.
+
+example: "Resource 'Michael Jackson' has been deleted."
+
+default: [ 'name', 'title' ]
+
+if no identifier is found the resource_key is used
+
 =head2 resultset_key
 
 stash key used to store the resultset of this resource. (e.g.: 'cds_rs')
@@ -313,15 +333,15 @@ documented in L<CatalystX::Resource>
 
 =head2 _redirect
 
-redirect request after create/edit/delete/move_next/move_previous
+redirect request after create/edit/delete
 
 =head2 _msg
 
 returns notification msg to be displayed
 
-=head2 _name
+=head2 _identifier
 
-get a meaningful name for the resource
+return an identifier for the resource
 
 =head1 ACTIONS
 
