@@ -1,6 +1,6 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Delete;
 {
-    $CatalystX::Resource::TraitFor::Controller::Resource::Delete::VERSION = '0.001_006';
+    $CatalystX::Resource::TraitFor::Controller::Resource::Delete::VERSION = '0.003_001';
 }
 
 use MooseX::MethodAttributes::Role;
@@ -14,8 +14,8 @@ requires qw/
     _redirect
     /;
 
-sub delete : Method('POST') Chained('base_with_id') PathPart('delete') Args(0)
-{
+sub delete : Method('POST') Chained('base_with_id') PathPart('delete')
+    Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
     my $msg = $self->_msg( $c, 'delete' );
@@ -36,7 +36,7 @@ CatalystX::Resource::TraitFor::Controller::Resource::Delete - a delete action fo
 
 =head1 VERSION
 
-version 0.001_006
+version 0.003_001
 
 =head1 ACTIONS
 
