@@ -1,6 +1,6 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Sortable;
 {
-    $CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.001_006';
+    $CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.003_001';
 }
 
 use MooseX::MethodAttributes::Role;
@@ -22,7 +22,7 @@ sub move_next : Method('POST') Chained('base_with_id') PathPart('move_next')
     my $resource = $c->stash->{ $self->resource_key };
     $resource->move_next;
     $c->flash( msg => $self->_msg( $c, 'move_next' ) );
-    $self->_redirect($c);
+    $c->res->redirect( $c->req->referer // '/' );
 }
 
 sub move_previous : Method('POST') Chained('base_with_id')
@@ -31,7 +31,16 @@ sub move_previous : Method('POST') Chained('base_with_id')
     my $resource = $c->stash->{ $self->resource_key };
     $resource->move_previous;
     $c->flash( msg => $self->_msg( $c, 'move_previous' ) );
-    $self->_redirect($c);
+    $c->res->redirect( $c->req->referer // '/' );
+}
+
+sub move_to : Method('POST') Chained('base_with_id') PathPart('move_to')
+    Args(1) {
+    my ( $self, $c, $pos ) = @_;
+    my $resource = $c->stash->{ $self->resource_key };
+    $resource->move_to($pos);
+    $c->flash( msg => $self->_msg( $c, 'move_to' ) );
+    $c->res->redirect( $c->req->referer // '/' );
 }
 
 1;
@@ -46,7 +55,7 @@ CatalystX::Resource::TraitFor::Controller::Resource::Sortable - makes your resou
 
 =head1 VERSION
 
-version 0.001_006
+version 0.003_001
 
 =head1 SYNOPSIS
 
@@ -98,6 +107,9 @@ Example: Artist has_many Albums has_many Songs
     # TestApp/Schema/Result/Resource/Song.pm
     __PACKAGE__->grouping_column('album_id');
 
+After a move operation you will always be redirected to the referer
+If no referer header is foudn you'll be redirected to '/'
+
 =head1 ACTIONS
 
 =head2 move_next
@@ -108,6 +120,10 @@ Example: Artist has_many Albums has_many Songs
 
     will switch the resource with the previous one
 
+=head2 move_to
+
+    move resource to denoted position
+
 =head1 AUTHOR
 
 David Schmidt <davewood@cpan.org>
