@@ -1,5 +1,6 @@
 package TestApp;
 use Moose;
+use File::Temp qw/ tempdir /;
 use namespace::autoclean;
 
 use Catalyst qw/
@@ -13,8 +14,11 @@ extends 'Catalyst';
 our $VERSION = '0.01';
 
 __PACKAGE__->config(
-    name        => 'TestApp',
-    session     => { flash_to_stash => 1 },
+    name              => 'TestApp',
+    'Plugin::Session' => {
+        storage        => tempdir( CLEANUP => 1 ),
+        flash_to_stash => 1,
+    },
     'Model::DB' => {
         connect_info => {
             dsn      => 'dbi:SQLite:' . __PACKAGE__->path_to('testdbic.db'),
@@ -57,15 +61,16 @@ __PACKAGE__->config(
         actions                => { base => { PathPart => 'artists', }, },
     },
     'Controller::Resource::Concert' => {
-        resultset_key    => 'concerts_rs',
-        resources_key    => 'concerts',
-        resource_key     => 'concert',
-        parent_key       => 'artist',
-        parents_accessor => 'concerts',
-        form_class       => 'TestApp::Form::Resource::Concert',
-        model            => 'DB::Resource::Concert',
-        traits           => ['-Delete'],
-        actions          => {
+        resultset_key      => 'concerts_rs',
+        resources_key      => 'concerts',
+        resource_key       => 'concert',
+        parent_key         => 'artist',
+        parents_accessor   => 'concerts',
+        form_class         => 'TestApp::Form::Resource::Concert',
+        model              => 'DB::Resource::Concert',
+        traits             => ['-Delete'],
+        identifier_columns => ['location'],
+        actions            => {
             base => {
                 PathPart => 'concerts',
                 Chained  => '/resource/artist/base_with_id',
@@ -103,6 +108,40 @@ __PACKAGE__->config(
             },
         },
     },
+    'Controller::Resource::Artwork' => {
+        resultset_key    => 'artworks_rs',
+        resources_key    => 'artworks',
+        resource_key     => 'artwork',
+        form_class       => 'TestApp::Form::Resource::Artwork',
+        model            => 'DB::Resource::Artwork',
+        parent_key       => 'album',
+        parents_accessor => 'artworks',
+        redirect_mode    => 'show_parent',
+        traits           => [ 'Sortable', '-List' ],
+        actions          => {
+            base => {
+                PathPart => 'artworks',
+                Chained  => '/resource/album/base_with_id',
+            },
+        },
+    },
+    'Controller::Resource::Lyric' => {
+        resultset_key    => 'lyrics_rs',
+        resources_key    => 'lyrics',
+        resource_key     => 'lyric',
+        form_class       => 'TestApp::Form::Resource::Lyric',
+        model            => 'DB::Resource::Lyric',
+        parent_key       => 'album',
+        parents_accessor => 'lyrics',
+        redirect_mode    => 'show',
+        traits           => ['Sortable'],
+        actions          => {
+            base => {
+                PathPart => 'lyrics',
+                Chained  => '/resource/album/base_with_id',
+            },
+        },
+    },
     'CatalystX::Resource' => {
         error_path  => '/error404',
         controllers => [
@@ -111,6 +150,8 @@ __PACKAGE__->config(
                 Resource::Concert
                 Resource::Album
                 Resource::Song
+                Resource::Artwork
+                Resource::Lyric
                 /
         ],
     },
